﻿using Janus.Core.Models;
using System;
using System.Collections.Generic;
using System.Text;

namespace Janus.Core.Interfaces
{
    /// <summary>
    /// This is interface for the parsers.
    /// Parser should be able to import dependecies of the solution/project selected.
    /// Implementation depends on project programming language.
    /// </summary>
    public interface IDependencyParser
    {
        /// <summary>
        /// This method parses a solution and all its subprojects, along with all dependencies.
        /// </summary>
        /// <param name="path">Path to the solution</param>
        /// <returns>Parsed solution in internal data structure</returns>
        public SolutionItem ParseSolution(string path);

        /// <summary>
        /// This method parses a project, along with all dependencies.
        /// </summary>
        /// <param name="path">Path to the project</param>
        /// <returns>Parsed project in internal data structure</returns>
        public ProjectItem ParseProject(string path);
    }
}
