﻿using Janus.Core.Models;
using Janus.Core.Models.Results;
using System;
using System.Collections.Generic;
using System.IO;
using System.Text;

namespace Janus.Core.Interfaces
{
    /// <summary>
    /// This interface is for importers.
    /// Should be enough for all the importers needs.
    /// Should mirror exporter cappabilities.
    /// </summary>
    public interface IImporter
    {
        /// <summary>
        /// Performs the import of the given file
        /// Decides, what is inside the file, then calls specialized methods
        /// </summary>
        /// <param name="filePath">Path to the file to be imported</param>
        /// <param name="skipValidation">If set to the true, skips the validation of the version</param>
        /// <returns>Imported data in internal data structure</returns>
        public ImportResult<DataSerializationWrapper> ImportWrapperFromFile(string filePath, bool skipValidation = false);

        /// <summary>
        /// Performs the import, reads the stream until the EOF is recieved
        /// Decides, what is inside the stream, then calls specialized methods
        /// </summary>
        /// <param name="stream">Stream to used to read the input</param>
        /// <param name="skipValidation">If set to the true, skips the validation of the version</param>
        /// <returns>Imported data in internal data structure</returns>
        public ImportResult<DataSerializationWrapper> ImportWrapperFromStream(TextReader stream, bool skipValidation = false);

        /// <summary>
        /// Performs the import of the given json representation
        /// Decides, what is inside the json data, then calls specialized methods
        /// </summary>
        /// <param name="jsonData">Data to be imported in json format</param>
        /// <param name="skipValidation">If set to the true, skips the validation of the version</param>
        /// <returns>Imported data in internal data structure</returns>
        public ImportResult<DataSerializationWrapper> ImportWrapperFromString(string jsonData, bool skipValidation = false);

        /// <summary>
        /// Import the exported solutions list.
        /// </summary>
        /// <param name="dataWrapper">Data wrapper with all data</param>
        /// <returns>Imported data in internal data structure</returns>
        public ImportResult<T> ImportData<T>(DataSerializationWrapper dataWrapper);
    }
}
