﻿using Janus.Core.Interfaces;
using System;
using System.Collections.Generic;
using System.IO;
using System.Text;

namespace Janus.Core.Models
{
    /// <summary>
    /// This class represents a solution.
    /// Solutions is collection of projects.
    /// </summary>
    public class SolutionItem : IComponentItem
    {

        /// <summary>
        /// Constructs and initializes the instance
        /// </summary>
        public SolutionItem()
        {
            Projects = new List<ProjectEdge>();
        }

        /// <summary>
        /// Constructs and initializes the instance, sets the given path and obtains project name (Same as project file)
        /// </summary>
        public SolutionItem(string path) : this()
        {
            Path = path;
            if (File.Exists(path))
            {
                Name = $"Solution-{System.IO.Path.GetFileNameWithoutExtension(path)}";
            }
        }

        /// <summary>
        /// Solution name
        /// </summary>
        public string Name { get; set; }

        /// <summary>
        /// Solution language
        /// </summary>
        public string Language { get; set; }

        /// <summary>
        /// Solution path
        /// </summary>
        public string Path { get; set; }

        /// <summary>
        /// List of projects
        /// </summary>
        public IList<ProjectEdge> Projects { get; set; }

        /// <summary>
        /// Prints the dependency tree in console
        /// </summary>
        /// <param name="indent">Indentation of the node</param>
        /// <param name="last">Marks the item as last, prints end of this branch</param>
        /// <param name="edgeInfo">Additional information about the edge</param>
        public string PrintPretty(string indent, bool last, string edgeInfo = "")
        {
            string dataResult = "";
            //Console.Write(indent);
            dataResult += indent;
            if (last)
            {
                //Console.Write("\\-");
                dataResult += "\\-";
                indent += "  ";
            }
            else
            {
                //Console.Write("|-");
                dataResult += "|-";
                indent += "| ";
            }
            //Console.WriteLine(this);
            dataResult += this.ToString() + "\n";

            for (int i = 0; i < Projects.Count; i++)
            {
                dataResult += Projects[i].Link.PrintPretty(indent, i == Projects.Count - 1);
            }

            return dataResult;
        }

        /// <summary>
        /// Prints object in string format
        /// </summary>
        /// <returns>Textual representation of the SolutionItem</returns>
        public override string ToString()
        {
            return $"{Name} ({Projects.Count} projects)";
        }
    }
}
